@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class JsRegex
   module Converter
     Dir[File.join(__dir__, 'converter', '*.rb')].sort.each do |file|
@@ -13,6 +15,7 @@ class JsRegex
       expression:  SubexpressionConverter,
       free_space:  FreespaceConverter,
       group:       GroupConverter,
+      keep:        KeepConverter,
       literal:     LiteralConverter,
       meta:        MetaConverter,
       nonproperty: PropertyConverter,
