@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative 'base'
 
 class JsRegex
@@ -10,8 +12,10 @@ class JsRegex
 
       def convert_data
         case subtype
-        when :bol, :bos then '^'
-        when :eol, :eos then '$'
+        when :bol then convert_bol
+        when :bos then '^'
+        when :eol then '(?=$|\n)'
+        when :eos then '$'
         when :eos_ob_eol then '(?=\n?$)'
         when :word_boundary then convert_boundary
         when :nonword_boundary then convert_nonboundary
@@ -20,6 +24,15 @@ class JsRegex
         end
       end
 
+      def convert_bol
+        if context.es_2018_or_higher?
+          '(?<=^|\n(?!$))'
+        else
+          # TODO: warn in v4.0.0, or drop ES2009 & ES2015 support
+          '^'
+        end
+      end
+
       def convert_boundary
         if context.es_2018_or_higher? && context.enable_u_option
           BOUNDARY_EXPANSION
