@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative 'base'
 require_relative 'literal_converter'
 
@@ -38,14 +40,14 @@ class JsRegex
         case subtype
         when :codepoint_list
           convert_codepoint_list
-        when :control, :meta_sequence
+        when :control, :meta_sequence, :utf8_hex
           unicode_escape_codepoint
         when :literal
           LiteralConverter.convert_data(expression.char, context)
+        when :bell, :escape, :hex, :octal
+          hex_escape_codepoint
         when *ESCAPES_SHARED_BY_RUBY_AND_JS
           pass_through
-        when :bell, :escape, :octal
-          hex_escape_codepoint
         else
           warn_of_unsupported_feature
         end
